@@ -97,7 +97,7 @@ use Padre::Config::Host    ();
 use Padre::Locale::T;
 use Padre::Logger;
 
-our $VERSION    = '0.98';
+our $VERSION    = '1.02';
 our $COMPATIBLE = '0.93';
 
 our ( %SETTING, %DEFAULT, %STARTUP, $REVISION, $SINGLETON );
@@ -1138,7 +1138,7 @@ setting(
 	name    => 'editor_file_size_limit',
 	type    => Padre::Constant::POSINT,
 	store   => Padre::Constant::HUMAN,
-	default => 500_000,
+	default => 5_000_000,
 );
 setting(
 	name    => 'editor_right_margin_enable',
@@ -1958,14 +1958,14 @@ a own value.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 
 This program is free software; you can redistribute it and/or modify it under the
 same terms as Perl 5 itself.
 
 =cut
 
-# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
