@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.00';
+our $VERSION = '1.02';
 
 #
 # Constructor.
@@ -67,8 +67,8 @@ sub apply {
 		# insert 'use strict; use warnings;' at the top
 		my $first = $doc->find_first(
 			sub {
-				return $_[1]->isa('PPI::Statement')
-					or $_[1]->isa('PPI::Structure');
+				return ($_[1]->isa('PPI::Statement')
+					or $_[1]->isa('PPI::Structure'));
 			}
 		);
 		$replace = "use strict;\nuse warnings;\n";
@@ -115,7 +115,7 @@ This ensures that you have the following in your script:
 	use strict;
 	use warnings;
 
-# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
