@@ -7,7 +7,7 @@ use Padre::Wx     ();
 use Padre::Util   ();
 use Padre::Plugin ();
 
-our $VERSION = '0.98';
+our $VERSION = '1.02';
 our @ISA     = 'Padre::Plugin';
 
 
@@ -268,6 +268,8 @@ sub _dump {
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Padre::Plugin::Devel - tools used by the Padre developers
@@ -308,7 +310,7 @@ Connects to C<#wxperl> on C<irc.perl.org>, where people can answer queries on wx
 
 =head1 AUTHOR
 
-Gábor Szabó
+Gábor Szabó;
 
 =head1 LICENSE
 
@@ -317,7 +319,7 @@ under the same terms as Perl itself.
 
 =cut
 
-# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
