@@ -1,6 +1,6 @@
 package Padre::SLOC;
 
-# A basic Source Lines of Code counter/accumulator
+# A basic "Source Lines of Code" counter/accumulator
 
 use 5.008;
 use strict;
@@ -8,7 +8,7 @@ use warnings;
 use Params::Util ();
 use Padre::MIME  ();
 
-our $VERSION    = '0.98';
+our $VERSION    = '1.02';
 our $COMPATIBLE = '0.95';
 
 # Differentiate content between different types
@@ -24,6 +24,7 @@ my %CONTENT = (
 	'text/x-adasrc'          => 'code',
 	'text/x-cobol'           => 'code',
 	'text/x-csrc'            => 'code',
+	'text/x-fsharp'          => 'code',
 	'text/x-haskell'         => 'code',
 	'text/x-java'            => 'code',
 	'text/x-pascal'          => 'code',
@@ -292,7 +293,7 @@ sub count_uncommented {
 
 1;
 
-# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
