@@ -6,7 +6,7 @@ use warnings;
 use Padre::Wx             ();
 use Padre::Wx::Role::Main ();
 
-our $VERSION = '1.00';
+our $VERSION = '1.02';
 our @ISA     = qw{
 	Padre::Wx::Role::Main
 	Wx::Dialog
@@ -76,7 +76,7 @@ sub new {
 	my $openurl_label = Wx::StaticText->new(
 		$self,
 		-1,
-		Wx::gettext('e.g.') . ' http://svn.perlide.org/padre/trunk/Padre/Makefile.PL',
+		Wx::gettext('e.g.') . ' https://github.com/PadreIDE/Padre/Makefile.PL',
 		Wx::DefaultPosition,
 		Wx::DefaultSize,
 	);
@@ -150,7 +150,7 @@ sub modal {
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
@@ -160,7 +160,7 @@ LICENSE file included with this module.
 
 =cut
 
-# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
