@@ -3,6 +3,7 @@ package Padre::Wx::Panel::Debugger;
 use 5.010;
 use strict;
 use warnings;
+no if $] > 5.017010, warnings => 'experimental::smartmatch';
 
 use utf8;
 use Padre::Util              ();
@@ -16,7 +17,7 @@ use Padre::Breakpoints       ();
 use Padre::Logger;
 use Debug::Client 0.20 ();
 
-our $VERSION = '0.98';
+our $VERSION = '1.02';
 our @ISA     = qw{
 	Padre::Wx::Role::View
 	Padre::Wx::FBP::Debugger
@@ -294,7 +295,7 @@ sub debug_perl {
 	#TODO how do we add debug options at startup such as threaded mode
 
 	# Set up the debugger
-	my $host = 'localhost';
+	my $host = '127.0.0.1';
 	my $port = 24642 + int rand(1000); # TODO make this configurable?
 	SCOPE: {
 		local $ENV{PERLDB_OPTS} = "RemotePort=$host:$port";
@@ -460,7 +461,7 @@ sub update_debug_user_interface {
 	my $output = shift;
 	my $main = $self->main;
 
-	my $module = $self->{client}->module;
+	my $module = $self->{client}->module || BLANK;
 	$self->{client}->get_lineinfo;
 
 	if ( $module eq '<TERMINATED>' ) {
@@ -1500,7 +1501,7 @@ Returns true if debugger successfully started.
 
 =cut
 
-# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2016 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
