@@ -6,6 +6,6 @@ my $name;
 
 print "Hello $name\n";
 my $x = "2x";
-print 3+$x;
+print 3+$x, "\n";
 
 print "done\n";
